@@ -16,18 +16,13 @@
 # You should have received a copy of the GNU General Public License
 # along with nrun.  If not, see <http://www.gnu.org/licenses/>.
 #
-# Program: Dispatcher.pm
-# Author:  Timo Benk <benk@b1-systems.de>
-# Date:    Thu May 9 08:08:32 2013 +0200
-# Ident:   03a00d9a9995d1ad059b127162589f3bdcebc8cc
-# Branch:  master
+# Program: <FILE>
+# Author:  <AUTHORNAME> <<AUTHOREMAIL>>
+# Date:    <COMMITTERDATE>
+# Ident:   <COMMITHASH>
+# Branch:  <BRANCH>
 #
-# Changelog:--reverse --grep '^tags.*relevant':-1:%an : %ai : %s
-# 
-# Timo Benk : 2013-04-28 17:27:31 +0200 : initial checkin
-# Timo Benk : 2013-05-08 09:48:13 +0200 : misplaced brace made callback_action() mandatory
-# Timo Benk : 2013-05-08 10:05:39 +0200 : better signal handling implemented
-# Timo Benk : 2013-05-08 15:11:24 +0200 : use symbolic names in kill()
+# <CHANGELOG:--reverse --grep '^tags.*relevant':-1:%an : %ai : %s>
 #
 
 package NRun::Dispatcher;
@@ -46,7 +41,6 @@ use Time::HiRes qw(usleep);
 #   'timeout' => timeout in seconds
 #   'objects' => the target objects
 #   'nmax'    => maximum number of parallel login processes
-
 #   'callback_action' => callback function to be executed in parallel
 #                        signature: my ($ret, $out) = sub callback_action ($object)
 #   'callback_result' => callback function to be executed to handle the 
@@ -134,10 +128,10 @@ sub run {
 
     my (@pool, %pids);
 
-    $SIG{USR1} = sub { kill(USR1 => keys(%pids)); };
-    $SIG{USR2} = sub { kill(USR2 => keys(%pids)); };
-    $SIG{INT}  = sub { kill(INT  => keys(%pids)); exit; };
-    $SIG{TERM} = sub { kill(TERM => keys(%pids)); exit; };
+    local $SIG{USR1} = sub { kill(USR1 => keys(%pids)); };
+    local $SIG{USR2} = sub { kill(USR2 => keys(%pids)); };
+    local $SIG{INT}  = sub { kill(INT  => keys(%pids)); exit; };
+    local $SIG{TERM} = sub { kill(TERM => keys(%pids)); exit; };
 
     # rampup
     while (scalar(@pool) < $_self->{nmax} and scalar(@{$_self->{objects}}) > 0) {
